import {Component, ElementRef, OnInit} from '@angular/core';
import {TooltipModule} from 'ngx-bootstrap/tooltip';
import {TabDirective} from "ngx-bootstrap/tabs";
import {AuthService} from "../serve-auth/auth.service";
import {NzMessageService} from 'ng-zorro-antd/message';

//卡片
interface CardItem {
  imagePreview: string;
  title: string;
  description: string;
}

@Component({
  selector: 'app-recommended-templates',
  templateUrl: './recommended-templates.component.html',
  styleUrls: ['./recommended-templates.component.scss']
})


export class RecommendedTemplatesComponent implements OnInit {
  //卡片
  constructor(private authService: AuthService, private message: NzMessageService) {

  }

  ngOnInit() {
    this.selectButton(1);
  }

  cardItems: CardItem[] = [];

  showOverlay = false;

  value?: string;

  onSelect(data: TabDirective): void {
    this.value = data.heading;
  }

  selectedButton: number = 0;
  selectNumber: number = 1
  selectLimit: number = 10

  //选择岗位模板分类
  async selectButton(buttonNumber: number): Promise<void> {
    this.selectedButton = buttonNumber;
    this.cardItems = await this.authService.parseGetResumeById("LjUserResumeData", {
      "postType": buttonNumber,
    }, this.selectLimit, this.selectNumber * this.cardItems.length)
    console.log(this.cardItems)

  }

  //判断是否触底
  isAttach = false

  onContainerScroll(event: Event) {
    const container = event.target as HTMLElement;
    const scrollHeight = container.scrollHeight;
    const scrollTop = container.scrollTop;
    const clientHeight = container.clientHeight;
    if (Math.round(scrollHeight - scrollTop) - 1 <= clientHeight && !this.isAttach) {
      // 容器已触底
      this.createBasicMessage("数据加载中")

      this.isAttach = true
      setTimeout(() => {
        this.loadData()
        this.isAttach = false
      }, 1000);
      // 在这里执行触底后的操作
    }
  }


  //选择分页条出现
  async loadData() {
    let list = await this.authService.parseGetResumeById("LjUserResumeData", {
      "postType": this.selectedButton,
    }, this.selectLimit, this.selectNumber * this.cardItems.length)
    if (list.length > 0) {
      this.cardItems = this.cardItems.concat(list);
    } else {
      this.createBasicMessage("数据已经枯竭")
    }
  }

  //全局提示已经全部加载
  createBasicMessage(message: string): void {
    this.message.info(message);
  }

  jobCategories: string[] = [
    '技术类职业',
    '商业和管理类职业',
    '医疗和健康类职业',
    '教育类职业',
    '媒体和传媒类职业',
    '艺术和设计类职业',
    '建筑和工程类职业',
    '零售和销售类职业',
    '金融和投资类职业',
    '法律和法务类职业'
  ];
  jobStyles: string[] = [
    '专业',
    '商务',
    '创意',
    '极简',
  ];

  temps: any = [];


}
