import {Injectable} from '@angular/core';
import * as Parse from "parse"

(Parse as any).serverURL = "https://web2023.fmode.cn/parse";
// https://web2023.fmode.cn/s0210490/api/user/login
Parse.initialize("dev")

@Injectable({
  providedIn: 'root'
})
export class AuthService {
  constructor() {
  }

  /*
  * 列表
  * @param table 表名
  * @param params 查询参数
  * @param limit 记录条数
  * @param skip 跳过多少条
  * @param result 返回字典格式
  * */
  public parseGetResumeById(table: string, params: any = null, limit: number = -1, skip: number = 0): Promise<any> {
    return new Promise<any>(async (resolve: any, reject: any) => {
      const query = new Parse.Query(table);
      if (limit !== -1) {
        query.limit(limit)
      }
      if (skip !== 0) {
        query.skip(skip)
      }
      if (params !== null) {
        for (let param in params) {
          query.equalTo(param, params[param])
        }
      }
      const result: any = await query.find();
      if (result === undefined || result === null) {
        reject('error')
      }
      resolve(result.map((item: any) => item.toJSON()))
    })

  }

  /*
  * 列表
  * @param username 用户名
  * */
  public parseCurrentNew(username: string): Promise<any> {
    return new Promise<any>(async (resolve: any, reject: any) => {
      try {
        let query = new Parse.Query(Parse.User);
        query.equalTo("username", username);
        let userInfo = await query.first();
        if (userInfo) {
          console.log(userInfo)
          localStorage.setItem("USER_AUTH", JSON.stringify(userInfo));
          resolve(userInfo);
        } else {
          resolve(null);
        }
      } catch (error) {
        reject(error);
      }
    });
  }

  /*
  * Boolean
  * @param tableName:string
  * @param creationTime:Date
  * */
  public deleteDataByCreationTime(tableName: string, creationTime: Date): Promise<void> {
    return new Promise<void>(async (resolve: any, reject: any) => {
      try {
        const query = new Parse.Query(tableName);
        query.lessThanOrEqualTo("createdAt", creationTime);
        const data = await query.first();
        console.log(data)
        if (data) {
          await data.destroy();
          resolve("删除完成");
        } else {
          reject(new Error("No data found with the given creation time."));
        }
      } catch (error) {
        reject(error);
      }
    });
  }


}
